@@ -1,7 +1,7 @@
 package Plack::Middleware::MethodOverride;
 use strict;
 use warnings;
-use base qw(Plack::Middleware);
+use parent qw(Plack::Middleware);
 __PACKAGE__->mk_accessors(qw(header));
 
 my %allowed_method = map { $_ => 1 } qw( GET HEAD POST PUT DELETE );
